@@ -1,17 +1,13 @@
-.onLoad <- function(libname, pkgname){
-  options(yatah_sep = "\\|")
-}
-
 #' Ranks
 #'
 #' Named vector of ranks
-#'
+#' @keywords internal
 .ranks <- c(k = "kingdom", p = "phylum", c = "class", o = "order",
             f = "family", g = "genus", s = "species", t = "strain")
 
 
 #' Characters allowed in lineages
-#'
+#' @keywords internal
 .allchr <- "[a-zA-Z0-9_\\-\\.\\[\\]]"
 
 
